@@ -1,7 +1,6 @@
 import pickle
-import sys
 import pytest
-from netaddr import IPAddress, IPNetwork
+from netaddr import IPAddress, IPNetwork, ZEROFILL
 
 
 def test_ipaddress_v6():
@@ -12,15 +11,21 @@ def test_ipaddress_v6():
     assert ip.format() == 'fe80::dead:beef'
     assert int(ip) == 338288524927261089654018896845083623151
     assert hex(ip) == '0xfe8000000000000000000000deadbeef'
-    if sys.version_info[0] > 2:
-        assert bytes(ip) == b'\xfe\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xde\xad\xbe\xef'
-    assert ip.bin == '0b11111110100000000000000000000000000000000000000000000000000000000000000000000000000000000000000011011110101011011011111011101111'
-    assert ip.bits() == '1111111010000000:0000000000000000:0000000000000000:0000000000000000:0000000000000000:0000000000000000:1101111010101101:1011111011101111'
+    assert bytes(ip) == b'\xfe\x80\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xde\xad\xbe\xef'
+    assert (
+        ip.bin
+        == '0b11111110100000000000000000000000000000000000000000000000000000000000000000000000000000000000000011011110101011011011111011101111'
+    )
+    assert (
+        ip.bits()
+        == '1111111010000000:0000000000000000:0000000000000000:0000000000000000:0000000000000000:0000000000000000:1101111010101101:1011111011101111'
+    )
     assert ip.words == (65152, 0, 0, 0, 0, 0, 57005, 48879)
 
 
 @pytest.mark.parametrize(
-    ('value', 'ipaddr', 'network', 'cidr', 'broadcast', 'netmask', 'hostmask', 'size'), [
+    ('value', 'ipaddr', 'network', 'cidr', 'broadcast', 'netmask', 'hostmask', 'size'),
+    [
         (
             'fe80::dead:beef/64',
             IPAddress('fe80::dead:beef'),
@@ -31,7 +36,8 @@ def test_ipaddress_v6():
             IPAddress('::ffff:ffff:ffff:ffff'),
             18446744073709551616,
         ),
-    ])
+    ],
+)
 def test_ipnetwork_v6(value, ipaddr, network, cidr, broadcast, netmask, hostmask, size):
     net = IPNetwork(value)
     assert net.ip == ipaddr
@@ -54,6 +60,7 @@ def test_iterhosts_v6():
         IPAddress('::ffff:192.0.2.7'),
     ]
 
+
 def test_ipnetwork_boolean_evaluation_v6():
     assert bool(IPNetwork('::/0'))
 
@@ -104,8 +111,8 @@ def test_ipaddress_netmask_v6():
 
 
 def test_objects_use_slots():
-    assert not hasattr(IPNetwork("::/64"), "__dict__")
-    assert not hasattr(IPAddress("::"), "__dict__")
+    assert not hasattr(IPNetwork('::/64'), '__dict__')
+    assert not hasattr(IPAddress('::'), '__dict__')
 
 
 def test_ipaddress_pickling_v6():
@@ -148,6 +155,7 @@ def test_ipv6_unicast_address_allocation_info():
     assert ip.info.IPv6_unicast[0].whois == 'whois.lacnic.net'
     assert ip.info.IPv6_unicast[0].status == 'ALLOCATED'
 
+
 def test_rfc6164_subnets():
     # Tests for /127 subnet
     assert list(IPNetwork('1234::/127')) == [
@@ -162,7 +170,11 @@ def test_rfc6164_subnets():
     assert IPNetwork('1234::').broadcast is None
 
     # Tests for /128 subnet
-    assert IPNetwork("1234::/128").network == IPAddress('1234::')
-    assert IPNetwork("1234::/128").broadcast is None
-    assert list(IPNetwork("1234::/128")) == [IPAddress('1234::')]
-    assert list(IPNetwork("1234::/128").iter_hosts()) == [IPAddress('1234::')]
+    assert IPNetwork('1234::/128').network == IPAddress('1234::')
+    assert IPNetwork('1234::/128').broadcast is None
+    assert list(IPNetwork('1234::/128')) == [IPAddress('1234::')]
+    assert list(IPNetwork('1234::/128').iter_hosts()) == [IPAddress('1234::')]
+
+
+def test_ipaddress_ignores_zerofill_when_parsing_ipv6():
+    assert IPAddress('fe80::', flags=ZEROFILL)
